# fuzzy-c-means
Fuzzy c-means Clustering

[![Build Status](https://semaphoreci.com/api/v1/ahmad88me/fuzzy-c-means/branches/master/badge.svg)](https://semaphoreci.com/ahmad88me/fuzzy-c-means)

## Description
This implementation is based on the paper
**FCM: The fuzzy c-means clustering algorithm**

*James C.Bezdek, Robert Ehrlich, and  William Full*

## To run the tests
`sh tests/run_tests.sh`

